PyTOA5: Utilities for TOA5 Files
================================

This library contains routines for the processing of data files in the TOA5 format.
Since this format is basically a CSV file with a specific header, this library primarily
provides functions to handle the header; the rest of the file can be read with Python's
`csv <https://docs.python.org/3/library/csv.html>`_ module. A function to read a TOA5
file into a `Pandas <https://pandas.pydata.org/>`_ DataFrame is also provided.

**The documentation is available at** https://haukex.github.io/pytoa5/

Author, Copyright, and License
------------------------------

Copyright (c) 2023-2024 Hauke Dämpfling (haukex@zero-g.net)
at the Leibniz Institute of Freshwater Ecology and Inland Fisheries (IGB),
Berlin, Germany, https://www.igb-berlin.de/

This library is free software: you can redistribute it and/or modify it under
the terms of the GNU Lesser General Public License as published by the Free
Software Foundation, either version 3 of the License, or (at your option) any
later version.

This library is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
details.

You should have received a copy of the GNU Lesser General Public License
along with this program. If not, see https://www.gnu.org/licenses/
